@@ -67,6 +67,22 @@ module Schleuder
                 with: /\A[[:graph:]\s]*\z/i,
               }
 
+    # Some users find it quite confusing when they click "reply-to" and the mail client 
+    # doesn't reply to the sender of the mail but the whole mailing list. For those lists it can be
+    # considered to set this value to true. The recipients will then receive e-mails
+    # where the "reply-to" header will contain the reply-to address
+    # of the sender and thus reply to the sender when clicking "reply-to" in a client.
+    # If no "reply-to" is set, the "from"-header of the original sender will be used.
+    # The default is off.
+    validates :set_reply_to_to_sender, boolean: true
+
+    # Some users find it confusing when the "from" does not contain the original sender
+    # but the list address. For those lists it can be considered to set the munged header.
+    # This will result in a "from"-header like this: "originalsender@original.com via list@list.com"
+    # The default is off.
+    validates :munge_from, boolean: true
+
+
     default_scope { order(:email) }
 
     def self.configurable_attributes
@@ -367,7 +383,7 @@ module Schleuder
             next
           end
           
-          subscription.send_mail(mail)
+          subscription.send_mail(mail, incoming_mail)
           
         rescue => exc
           msg = I18n.t('errors.delivery_error',
