@@ -1,6 +1,6 @@
 class FingerprintValidator <  ActiveModel::EachValidator
   def validate_each(record, attribute, value)
-    unless value =~ /\A[a-f0-9]{32,}\z/i
+    unless GPGME::Key.valid_fingerprint?(value)
       record.errors[attribute] << (options[:message] || I18n.t("errors.invalid_fingerprint"))
     end
   end
