@@ -39,7 +39,8 @@ describe Schleuder::Runner do
         Schleuder::Runner.new().run(mail, list.email)
         message = Mail::TestMailer.deliveries.first
         content_part = message.parts.first
-        pseudoheaders = "From: Nina Siessegger <schleuder@example.org>\nSig: Unsigned"
+        separator = '------------------------------------------------------------------------------'
+        pseudoheaders = "From: Nina Siessegger <schleuder@example.org>\nSig: Unsigned\n#{separator}\n"
 
         expect(content_part.parts.first.body).to include(pseudoheaders)
         expect(content_part.parts.first.body).not_to include('To:')
@@ -92,6 +93,41 @@ describe Schleuder::Runner do
         teardown_list_and_mailer(list)
       end
 
+      it 'contains the Autocrypt header if include_autocrypt_header is set to true' do
+        list = create(
+          :list,
+          send_encrypted_only: false,
+          include_autocrypt_header: true,
+        )
+        list.subscribe('admin@example.org', nil, true)
+        mail = File.read('spec/fixtures/mails/plain/thunderbird.eml')
+        
+        Schleuder::Runner.new().run(mail, list.email)
+        message = Mail::TestMailer.deliveries.first
+
+        keydata = list.key_minimal_base64_encoded.gsub(/(.{78})/, '\1 ')
+        expect(message.header['Autocrypt'].to_s).to eq("addr=#{list.email}; prefer-encrypt=mutual; keydata=#{keydata}")
+        
+        teardown_list_and_mailer(list)
+      end
+      
+      it 'does not contain the Autocrypt header if include_autocrypt_header is set to false' do
+        list = create(
+          :list,
+          send_encrypted_only: false,
+          include_autocrypt_header: false,
+        )
+        list.subscribe('admin@example.org', nil, true)
+        mail = File.read('spec/fixtures/mails/plain/thunderbird.eml')
+        
+        Schleuder::Runner.new().run(mail, list.email)
+        message = Mail::TestMailer.deliveries.first
+        
+        expect(message.header.to_s).to_not include('Autocrypt')
+        
+        teardown_list_and_mailer(list)
+      end
+
       it "contains the list headers if include_list_headers is set to true" do
         list = create(
           :list,
@@ -182,6 +218,54 @@ describe Schleuder::Runner do
       end
     end
 
+    context 'mails not encrypted to the list key' do
+      it 'handles a mail which was encrypted to an absent key and returns DecryptionFailed error' do
+        list = create(
+          :list,
+          send_encrypted_only: false
+        )
+        list.subscribe("schleuder@example.org", nil, true)
+        mail = File.read('spec/fixtures/mails/encrypted-to-absent-key.txt')
+
+        result = Schleuder::Runner.new().run(mail, list.email)
+
+
+        expect(result.class).to eql(Schleuder::Errors::DecryptionFailed)
+
+        teardown_list_and_mailer(list)
+      end
+
+      it 'handles a mail which was encrypted to a passphrase and returns DecryptionFailed error' do
+        list = create(
+          :list,
+          send_encrypted_only: false
+        )
+        list.subscribe("schleuder@example.org", nil, true)
+        mail = File.read('spec/fixtures/mails/encrypted-to-passphrase.txt')
+
+        result = Schleuder::Runner.new().run(mail, list.email)
+        
+        expect(result.class).to eql(Schleuder::Errors::DecryptionFailed)
+
+        teardown_list_and_mailer(list)
+      end
+
+      it 'handles a mail containing PGP-garbage and returns DecryptionFailed error' do
+        list = create(
+          :list,
+          send_encrypted_only: false
+        )
+        list.subscribe("schleuder@example.org", nil, true)
+        mail = File.read('spec/fixtures/mails/containing-pgp-garbage.txt')
+
+        result = Schleuder::Runner.new().run(mail, list.email)
+
+        expect(result.class).to eql(Schleuder::Errors::DecryptionFailed)
+
+        teardown_list_and_mailer(list)
+      end
+    end
+
     it "delivers a signed error message if a subscription's key is expired on a encrypted-only list" do
         list = create(:list, send_encrypted_only: true)
         list.subscribe("admin@example.org", nil, true, false)
@@ -473,6 +557,43 @@ describe Schleuder::Runner do
 
       teardown_list_and_mailer(list)
     end
+
+    it 'falling back works also with non-ascii content' do
+      list = create(:list, send_encrypted_only: false)
+      list.subscribe("admin@example.org", "59C71FB38AEE22E091C78259D06350440F759BD3", true)
+
+      # manually build a specific mail structure that comes without a charset
+      mail = Mail.new
+      mail.from = "admin@example.org"
+      mail.to = list.request_address
+      ENV['GNUPGHOME'] = list.listdir
+      cipher_data = GPGME::Data.new
+      GPGME::Ctx.new({armor: true}) do |ctx|
+        ctx.add_signer(*GPGME::Key.find(:secret, "59C71FB38AEE22E091C78259D06350440F759BD3", :sign))
+        ctx.encrypt_sign(
+          GPGME::Key.find(:public,list.fingerprint, :encrypt),
+          GPGME::Data.new("Content-Type: text/plain\n\nNür ein test\n"),
+          cipher_data, 0
+        )
+        cipher_data.seek(0)
+      end
+
+      mail.content_type "multipart/encrypted; boundary=\"#{mail.boundary}\"; protocol=\"application/pgp-encrypted\""
+      ver_part = Mail::Part.new do
+        body "Version: 1"
+        content_type "application/pgp-encrypted"
+      end
+      mail.add_part ver_part
+      enc_part = Mail::Part.new do
+        body cipher_data.to_s
+        content_type "application/octet-stream"
+      end
+      mail.add_part enc_part
+      output = process_mail(mail.to_s, list.email)
+      expect(output).to be nil
+
+      teardown_list_and_mailer(list)
+    end
   end
 
 end
